[aarch32] RFR: u191 and u192

Sergey Nazarkin snazarkin at azul.com
Mon Oct 22 15:44:10 UTC 2018


Hi!

I’ve integrated changes for u191 and u192 update release. There only few minor aarch32 specific changes introduced by u192: 

diff -r 06bcb86ada42 -r 44ea54ccac16 src/cpu/aarch32/vm/vtableStubs_aarch32.cpp
--- a/src/cpu/aarch32/vm/vtableStubs_aarch32.cpp        Mon Oct 22 17:16:07 2018 +0300
+++ b/src/cpu/aarch32/vm/vtableStubs_aarch32.cpp        Mon Oct 22 18:28:41 2018 +0300
@@ -107,7 +107,7 @@
   __ flush();

   if (PrintMiscellaneous && (WizardMode || Verbose)) {
-    tty->print_cr("vtable #%d at "PTR_FORMAT"[%d] left over: %d",
+    tty->print_cr("vtable #%d at " PTR_FORMAT "[%d] left over: %d",
                   vtable_index, p2i(s->entry_point()),
                   (int)(s->code_end() - s->entry_point()),
                   (int)(s->code_end() - __ pc()));
diff -r 06bcb86ada42 -r 44ea54ccac16 src/os_cpu/linux_aarch32/vm/os_linux_aarch32.cpp
--- a/src/os_cpu/linux_aarch32/vm/os_linux_aarch32.cpp  Mon Oct 22 17:16:07 2018 +0300
+++ b/src/os_cpu/linux_aarch32/vm/os_linux_aarch32.cpp  Mon Oct 22 18:28:41 2018 +0300
@@ -517,8 +517,8 @@
 //    pthread_attr_getstack()

 static void current_stack_region(address * bottom, size_t * size) {
-  if (os::Linux::is_initial_thread()) {
-     // initial thread needs special handling because pthread_getattr_np()
+  if (os::is_primordial_thread()) {
+     // primordial thread needs special handling because pthread_getattr_np()
      // may return bogus value.
      *bottom = os::Linux::initial_thread_stack_bottom();
      *size   = os::Linux::initial_thread_stack_size();

Build verified with SPEC2008

/Sergey


More information about the aarch32-port-dev mailing list